@@ -14,6 +14,8 @@ import dropbox
 from pathlib import Path
 from io import StringIO
 
+import pickle
+
 @contextlib.contextmanager
 def stopwatch(message):
     """Context manager to print how long a block of code took."""
@@ -31,6 +33,13 @@ class NaPoleonDropboxConnector(object):
         self.overwrite = overwrite
         self.dropbox_backup = dropbox_backup
 
+    def download_pkl(self,pkl_file_name = ''):
+        bytes_data_pkl = self.download('', '', pkl_file_name)
+        #string_data_csv = StringIO(str(bytes_data_csv, 'utf-8'))
+        deserialized = pickle.loads(bytes_data_pkl)
+        #pickle.load(bytes_data_pkl, encoding='latin-1')
+        return deserialized
+
     def download_csv(self, csv_file_name = '', sep = ',', index_date = False):
         bytes_data_csv = self.download('', '', csv_file_name)
         string_data_csv = StringIO(str(bytes_data_csv, 'utf-8'))
