@@ -54,5 +54,9 @@ def indice_rebalancing(price_data= None, inception_date=None, target_weights=Non
     weights_df = pd.DataFrame(weights_list)
     weights_df.index = pd.to_datetime(weights_df['Date'])
     weights_df.drop('Date', axis=1, inplace=True)
+
+    for me_constituent in constituents:
+        weights_df[me_constituent] = weights_df[me_constituent] / weights_df['indice']
+
     weights_df['indice'] = weights_df['indice']*initial_value
     return weights_df
